
# Type: typeof


Names a parent type

URI: [meta:typeof](https://w3id.org/biolink/biolinkml/meta/typeof)


## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | the target type definition of the typeof slot is referred to as the "parent type" |
|  | | the type definition containing the typeof slot is referred to as the "child type" |
|  | | type definitions without a typeof slot are referred to as a "root type" |

